@@ -1,8 +1,9 @@
 use tokio::net::{TcpListener, TcpStream};
 use tokio_util::codec::{Framed};
 use futures::StreamExt;
-use tokio::io::AsyncWriteExt;
+
 use tokio_netstring::NetStringCodec;
+use futures::sink::SinkExt;
 
 
 async fn server() {
@@ -26,10 +27,10 @@ async fn server() {
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
     let serv_handle = tokio::spawn(server());
 
-    let mut stream = TcpStream::connect("127.0.0.1:7979").await?;
+    let stream = TcpStream::connect("127.0.0.1:7979").await?;
+    let mut framed_stream = Framed::new(stream, NetStringCodec {});
     // Write some data.
-    stream.write_all(b"5:hello,").await?;
-    stream.write_all(b"6:tokio!,").await?;
+    framed_stream.send("hello".to_string()).await?;
 
     let _ = serv_handle.await;
 
